AssistantModel class

Constructors

AssistantModel({required String id, required String object, required int createdAt, required String name, required String description, required String model, required dynamic instructions, required List<Tool> tools, required List fileIds, required Metadata metadata})
AssistantModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt ↔ int
getter/setter pair
description ↔ String
getter/setter pair
fileIds ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
instructions ↔ dynamic
getter/setter pair
metadata ↔ Metadata
getter/setter pair
model ↔ String
getter/setter pair
name ↔ String
getter/setter pair
object ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tools ↔ List<Tool>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited